@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2019-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -29,7 +25,7 @@ import univention.admin.password
 import univention.admin.samba
 import univention.admin.uexceptions
 import univention.admin.uldap
-from univention.admin import nagios
+from univention.admin import appcenter, nagios
 from univention.admin.certificate import PKIIntegration
 from univention.admin.guardian_roles import GuardianBase
 
@@ -40,7 +36,7 @@ translation = univention.admin.localization.translation('univention.admin.handle
 _ = translation.translate
 
 
-class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, PKIIntegration, GuardianBase):
+class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, PKIIntegration, GuardianBase, appcenter.AppHost):
     """|UDM| module for generic computer objects."""
 
     CONFIG_NAME: str = None
@@ -132,7 +128,7 @@ class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, P
                 krb_keys = univention.admin.password.krb5_asn1(self.krb5_principal(), self['password'])
                 al.append(('krb5Key', self.oldattr.get('password', [b'1']), krb_keys))
             if 'posix' in self.options:
-                password_crypt = "{crypt}%s" % (univention.admin.password.crypt(self['password']))
+                password_crypt = '{crypt}%s' % (univention.admin.password.crypt(self['password']))
                 al.append(('userPassword', self.oldattr.get('userPassword', [b''])[0], password_crypt.encode('ASCII')))
             if 'samba' in self.options:
                 password_nt, password_lm = univention.admin.password.ntlm(self['password'])
@@ -179,6 +175,10 @@ class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, P
         #        group.modify(ignore_license=True)
 
         self.nagios_ldap_post_remove()
+
+        if self.SERVER_ROLE:
+            self.app_host_ldap_post_remove()
+
         # Need to clean up oldinfo. If remove was invoked, because the
         # creation of the object has failed, the next try will result in
         # a 'object class violation' (Bug #19343)
@@ -218,7 +218,7 @@ class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, P
 
         if self.hasChanged('name'):
             if 'posix' in self.options:
-                requested_uid = "%s$" % self['name']
+                requested_uid = '%s$' % self['name']
                 try:
                     if not self.exists() or self['name'].lower() != self.oldinfo['name'].lower():
                         requested_uid = self.request_lock('uid', requested_uid)
@@ -240,7 +240,7 @@ class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, P
                 ml.append(('krb5Key', self.oldattr.get('password', [b'1']), krb_keys))
                 ml.append(('krb5KeyVersionNumber', self.oldattr.get('krb5KeyVersionNumber', []), krb_key_version.encode('ASCII')))
             if 'posix' in self.options:
-                password_crypt = "{crypt}%s" % (univention.admin.password.crypt(self['password']))
+                password_crypt = '{crypt}%s' % (univention.admin.password.crypt(self['password']))
                 ml.append(('userPassword', self.oldattr.get('userPassword', [b''])[0], password_crypt.encode('ASCII')))
             if 'samba' in self.options:
                 password_nt, password_lm = univention.admin.password.ntlm(self['password'])
@@ -277,10 +277,12 @@ class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, P
     def link(self) -> list[dict[str, str]] | None:
         result = []
         if self['ip'] and self['ip'] and self['ip'][0]:
-            result = [{
-                'url': 'https://%s/univention-management-console/' % self['ip'][0],
-                'ipaddr': self['ip'][0],
-            }]
+            result = [
+                {
+                    'url': 'https://%s/univention-management-console/' % self['ip'][0],
+                    'ipaddr': self['ip'][0],
+                },
+            ]
         if 'dnsEntryZoneForward' in self and self['dnsEntryZoneForward'] and self['dnsEntryZoneForward']:
             zone = univention.admin.uldap.explodeDn(self['dnsEntryZoneForward'][0], 1)[0]
             if not result:
@@ -304,7 +306,7 @@ class ComputerObject(univention.admin.handlers.simpleComputer, nagios.Support, P
             filter.transform_to_conjunction(univention.admin.filter.conjunction('|', [
                 univention.admin.filter.expression('aRecord', filter.value, escape=False),
                 univention.admin.filter.expression('aAAARecord', filter.value, escape=False),
-            ]))
+            ]))  # fmt: skip
         elif filter.variable == 'dnsAlias':
             found = univention.admin.filter.parse(univention.admin.handlers.dns.alias.lookup_alias_filter(lo, str(filter)))
             if isinstance(found, univention.admin.filter.conjunction):
