@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2017-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -31,12 +27,12 @@ def is_dns(attr: udm_handlers._Attributes) -> bool:
 
 def is_zone(attr: udm_handlers._Attributes) -> bool:
     """Are the given LDAP attributes a DNS zone entry?"""
-    return bool(attr.get("sOARecord"))
+    return bool(attr.get('sOARecord'))
 
 
 def is_reverse_zone(attr: udm_handlers._Attributes) -> bool:
     """Are the given LDAP attributes a DNS entry in a forward zone?"""
-    return attr["zoneName"][0].decode("ASCII").endswith((ARPA_IP4, ARPA_IP6))
+    return attr['zoneName'][0].decode('ASCII').endswith((ARPA_IP4, ARPA_IP6))
 
 
 def is_forward_zone(attr: udm_handlers._Attributes) -> bool:
@@ -56,6 +52,7 @@ def is_not_handled_by_other_module_than(attr: udm_handlers._Attributes, module:
 
 
 class DNSBase(udm_handlers.simpleLdap):
+    """Base class for dns/* modules"""
 
     def __init__(
         self,
@@ -95,7 +92,7 @@ class DNSBase(udm_handlers.simpleLdap):
         dn = superordinate.dn
         for rdn in str2dn(dn):
             for k, v, _t in rdn:
-                if k.lower() == "zonename":
+                if k.lower() == 'zonename':
                     return v
         raise ValueError(dn)
 
