@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2018-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -29,6 +25,7 @@ short_description = 'DNS: NS Record'
 object_name = 'Nameserver record'
 object_name_plural = 'Nameserver records'
 long_description = _('Delegate a subzone to other nameservers.')
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -75,6 +72,7 @@ mapping = univention.admin.mapping.mapping()
 mapping.register('zone', 'relativeDomainName', None, univention.admin.mapping.ListToString, encoding='ASCII')
 mapping.register('nameserver', 'nSRecord', encoding='ASCII')
 mapping.register('zonettl', 'dNSTTL', univention.admin.mapping.mapUNIX_TimeInterval, univention.admin.mapping.unmapUNIX_TimeInterval)
+# fmt: on
 
 
 class object(DNSBase):
@@ -86,7 +84,7 @@ class object(DNSBase):
             univention.admin.filter.expression('objectClass', 'dNSZone'),
             univention.admin.filter.expression('nSRecord', '*', escape=False),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('sOARecord', '*', escape=False)]),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
@@ -95,8 +93,5 @@ lookup_filter = object.lookup_filter
 
 def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
     return bool(
-        attr.get('nSRecord')
-        and is_dns(attr)
-        and not is_zone(attr)
-        and is_not_handled_by_other_module_than(attr, module),
+        attr.get('nSRecord') and is_dns(attr) and not is_zone(attr) and is_not_handled_by_other_module_than(attr, module),
     )
