@@ -1,8 +1,4 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -43,6 +39,7 @@ long_description = ''
 operations = ['search', 'edit', 'add', 'remove']
 
 
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -115,6 +112,7 @@ mapping.register('description', 'description', None, univention.admin.mapping.Li
 mapping.register('checkCommand', 'univentionNagiosCheckCommand', None, univention.admin.mapping.ListToString)
 mapping.register('checkArgs', 'univentionNagiosCheckArgs', None, univention.admin.mapping.ListToString)
 mapping.register('useNRPE', 'univentionNagiosUseNRPE', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -165,8 +163,8 @@ class object(univention.admin.handlers.simpleLdap):
                 except KeyError:
                     raise univention.admin.uexceptions.valueError(_('The host "%s" is invalid, it has no "cn" attribute.') % (hostdn,), property='assignedHosts')
 
-                domain: bytes = host.get('associatedDomain', [configRegistry.get("domainname").encode('ASCII')])[0]
-                hostlist.append(b"%s.%s" % (cn, domain))
+                domain: bytes = host.get('associatedDomain', [configRegistry.get('domainname').encode('ASCII')])[0]
+                hostlist.append(b'%s.%s' % (cn, domain))
 
             ml.insert(0, ('univentionNagiosHostname', self.oldattr.get('univentionNagiosHostname', []), hostlist))
 
