@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -32,6 +28,7 @@ short_description = _('Networks: Network')
 object_name = _('Network')
 object_name_plural = _('Networks')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -115,6 +112,7 @@ layout = [
         ]),
     ]),
 ]
+# fmt: on
 
 
 def rangeMap(value, encoding=()):
@@ -125,6 +123,7 @@ def rangeUnmap(value, encoding=()):
     return [x.decode(*encoding).split(' ') for x in value]
 
 
+# fmt: off
 mapping = univention.admin.mapping.mapping()
 mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('network', 'univentionNetwork', None, univention.admin.mapping.ListToString, encoding='ASCII')
@@ -134,6 +133,7 @@ mapping.register('dnsEntryZoneForward', 'univentionDnsForwardZone', univention.a
 mapping.register('dnsEntryZoneReverse', 'univentionDnsReverseZone', univention.admin.mapping.IgnoreNone, univention.admin.mapping.ListToString, encoding='ASCII')
 mapping.register('dhcpEntryZone', 'univentionDhcpEntry', univention.admin.mapping.IgnoreNone, univention.admin.mapping.ListToString, encoding='ASCII')
 mapping.register('ipRange', 'univentionIpRange', rangeMap, rangeUnmap, encoding='ASCII')
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -240,10 +240,7 @@ class object(univention.admin.handlers.simpleLdap):
                     if i != j:
                         otherFirstIP = ipaddress.ip_address('%s' % j[0])
                         otherLastIP = ipaddress.ip_address('%s' % j[1])
-                        if firstIP < otherFirstIP < lastIP or \
-                                firstIP < otherLastIP < lastIP or \
-                                otherFirstIP < firstIP < otherLastIP or \
-                                otherFirstIP < lastIP < otherLastIP:
+                        if firstIP < otherFirstIP < lastIP or firstIP < otherLastIP < lastIP or otherFirstIP < firstIP < otherLastIP or otherFirstIP < lastIP < otherLastIP:
                             raise univention.admin.uexceptions.rangesOverlapping('%s-%s; %s-%s' % (i[0], i[1], j[0], j[1]))
                 if firstIP not in network or lastIP not in network:
                     raise univention.admin.uexceptions.rangeNotInNetwork('%s-%s' % (firstIP, lastIP))
