@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -37,8 +33,8 @@ module = 'policies/repositorysync'
 operations = ['add', 'edit', 'remove', 'search']
 
 policy_oc = 'univentionPolicyRepositorySync'
-policy_apply_to = ["computers/domaincontroller_master", "computers/domaincontroller_backup", "computers/domaincontroller_slave", "computers/memberserver"]
-policy_position_dn_prefix = "cn=repository,cn=update"
+policy_apply_to = ['computers/domaincontroller_master', 'computers/domaincontroller_backup', 'computers/domaincontroller_slave', 'computers/memberserver']
+policy_position_dn_prefix = 'cn=repository,cn=update'
 
 childs = False
 short_description = _('Policy: Repository synchronisation')
@@ -46,6 +42,7 @@ object_name = _('Repository synchronisation policy')
 object_name_plural = _('Repository synchronisation policies')
 policy_short_description = _('Repository synchronisation')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -117,6 +114,7 @@ layout = [
 mapping = univention.admin.mapping.mapping()
 mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
@@ -148,8 +146,7 @@ class object(univention.admin.handlers.simplePolicy):
     def __getitem__(self, key):
         value = univention.admin.handlers.simplePolicy.__getitem__(self, key)  # need this first to initialize policy-results
         # set cron if we are in resultmode
-        if self.resultmode and hasattr(self, 'policy_attrs') and 'univentionRepositoryCron' in self.policy_attrs \
-                and (not self.cron_parsed):
+        if self.resultmode and hasattr(self, 'policy_attrs') and 'univentionRepositoryCron' in self.policy_attrs and (not self.cron_parsed):
             self.parse_cron(self.policy_attrs['univentionRepositoryCron']['value'][0])
             if not self.cron_parsed:
                 self.save()
@@ -162,7 +159,6 @@ class object(univention.admin.handlers.simplePolicy):
     def _ldap_modlist(self):
         ml = univention.admin.handlers.simplePolicy._ldap_modlist(self)
         if self.hasChanged(['minute', 'hour', 'day', 'month', 'weekday']):
-
             cron = {}
             if self.has_property('minute'):
                 cron['minute'] = self['minute']
