@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -33,6 +29,7 @@ object_name = _('Extended attribute')
 object_name_plural = _('Extended attributes')
 long_description = ''
 
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -321,6 +318,7 @@ mapping.register('version', 'univentionUDMPropertyVersion', None, univention.adm
 mapping.register('CLIName', 'univentionUDMPropertyCLIName', None, univention.admin.mapping.ListToString)
 mapping.register('options', 'univentionUDMPropertyOptions')
 mapping.register('preventUmcDefaultPopup', 'univentionUDMPropertyPreventUmcDefaultPopup', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -386,7 +384,7 @@ class object(univention.admin.handlers.simpleLdap):
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'univentionUDMProperty'),
             univention.admin.filter.expression('univentionUDMPropertyVersion', '2'),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
