@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -48,6 +44,7 @@ short_description = _('Printer share: Printer')
 object_name = _('Printer')
 object_name_plural = _('Printers')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -147,6 +144,7 @@ layout = [
         ]),
     ]),
 ]
+# fmt: on
 
 
 _AVAILABLE_PRINTER_SCHEMAS: list[str] = []
@@ -171,6 +169,7 @@ def mapPrinterURI(value: list[str], encoding: tuple[str, ...] = ()) -> bytes:
     return ''.join(value).encode(*encoding)
 
 
+# fmt: off
 mapping = univention.admin.mapping.mapping()
 mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('location', 'univentionPrinterLocation', None, univention.admin.mapping.ListToString)
@@ -182,6 +181,7 @@ mapping.register('sambaName', 'univentionPrinterSambaName', None, univention.adm
 mapping.register('ACLUsers', 'univentionPrinterACLUsers')
 mapping.register('ACLGroups', 'univentionPrinterACLGroups')
 mapping.register('ACLtype', 'univentionPrinterACLtype', None, univention.admin.mapping.ListToString, encoding='ASCII')
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -210,7 +210,7 @@ class object(univention.admin.handlers.simpleLdap):
         univention.admin.handlers.simpleLdap.open(self)
         if self['model']:
             models = univention.admin.modules._get('settings/printermodel').lookup(None, self.lo, filter_format('printerModel="%s*', [self['model']]))
-            log.debug("printermodel: %s", models)
+            log.debug('printermodel: %s', models)
             if not models or len(models) > 1:
                 self['producer'] = []
             else:
@@ -228,11 +228,11 @@ class object(univention.admin.handlers.simpleLdap):
 
         for schema in _AVAILABLE_PRINTER_SCHEMAS:
             if protocol.startswith(schema):
-                if schema.endswith(":/") and protocol.endswith("://"):
+                if schema.endswith(':/') and protocol.endswith('://'):
                     protocol = protocol[:-1]
                     host = '/' + host
 
-                if protocol.endswith(":/") and host == "/" and schema.endswith("://"):
+                if protocol.endswith(':/') and host == '/' and schema.endswith('://'):
                     raise univention.admin.uexceptions.valueInvalidSyntax(_('Protocol and destination parts can not be parsed.'))
 
         self['uri'] = [protocol, host]
@@ -250,7 +250,9 @@ class object(univention.admin.handlers.simpleLdap):
                 if member_cn == self.info['name']:
                     rm_attrib.append(pg_dn)
                     if len(member_list['univentionPrinterGroupMember']) < 2:
-                        raise univention.admin.uexceptions.emptyPrinterGroup(_('%(name)s is the last member of the printer group %(group)s. ') % {'name': self.info['name'], 'group': member_list['cn'][0].decode('UTF-8')})
+                        raise univention.admin.uexceptions.emptyPrinterGroup(
+                            _('%(name)s is the last member of the printer group %(group)s. ') % {'name': self.info['name'], 'group': member_list['cn'][0].decode('UTF-8')},
+                        )
 
         printergroup_module = univention.admin.modules._get('shares/printergroup')
         for rm_dn in rm_attrib:
