@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2018-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -35,6 +31,7 @@ object_name = _('Contact')
 object_name_plural = _('Contact information')
 long_description = _('Contact information')
 
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -322,6 +319,7 @@ mapping.register('homeTelephoneNumber', 'homePhone')
 mapping.register('mobileTelephoneNumber', 'mobile')
 mapping.register('pagerTelephoneNumber', 'pager')
 mapping.register('homePostalAddress', 'homePostalAddress', mapHomePostalAddress, unmapHomePostalAddress)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -371,7 +369,9 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _modlist_display_name(self, ml: list[tuple[str, Any, Any]]) -> list[tuple[str, Any, Any]]:
         # update displayName automatically if no custom value has been entered by the user and the name changed
-        if self.info.get('displayName') == self.oldinfo.get('displayName') and (self.info.get('firstname') != self.oldinfo.get('firstname') or self.info.get('lastname') != self.oldinfo.get('lastname')):
+        if self.info.get('displayName') == self.oldinfo.get('displayName') and (
+            self.info.get('firstname') != self.oldinfo.get('firstname') or self.info.get('lastname') != self.oldinfo.get('lastname')
+        ):
             prop_displayName = self.descriptions['displayName']
             old_default_displayName = prop_displayName._replace(prop_displayName.base_default, self.oldinfo)
             # does old displayName match with old default displayName?
@@ -429,7 +429,7 @@ class object(univention.admin.handlers.simpleLdap):
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'simpleSecurityObject')]),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'uidObject')]),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'pkiUser')]),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
@@ -438,7 +438,12 @@ lookup_filter = object.lookup_filter
 
 def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
     # FIXME: is this if block needed? copy pasted from users/user
-    if b'0' in attr.get('uidNumber', []) or b'$' in attr.get('uid', [b''])[0] or b'univentionHost' in attr.get('objectClass', []) or b'functional' in attr.get('univentionObjectFlag', []):
+    if (
+        b'0' in attr.get('uidNumber', [])
+        or b'$' in attr.get('uid', [b''])[0]
+        or b'univentionHost' in attr.get('objectClass', [])
+        or b'functional' in attr.get('univentionObjectFlag', [])
+    ):
         return False
 
     required_ocs = {b'person', b'inetOrgPerson', b'organizationalPerson'}
