@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -311,7 +307,7 @@ def unmapBase64(value: list[bytes] | tuple[bytes, ...] | bytes) -> list[str] | s
             return base64.b64encode(value[0]).decode('ASCII')
         except Exception as e:
             log.error('ERROR in unmapBase64: %s', e)
-    return ""
+    return ''
 
 
 def mapBase64(value: list[str] | str) -> list[bytes] | bytes:
@@ -343,7 +339,7 @@ def mapBase64(value: list[str] | str) -> list[bytes] | bytes:
             return base64.b64decode(value)
         except Exception as e:
             log.error('ERROR in mapBase64: %s', e)
-    return ""
+    return ''
 
 
 def BooleanListToString(list: list[bytes], encoding: _Encoding = ()) -> str:
