@@ -1,13 +1,8 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2019-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """|UDM| type definitions."""
 
-
 import datetime
 import inspect
 import time
@@ -278,7 +273,6 @@ class BooleanType(TypeHint):
 
 
 class TriBooleanType(BooleanType):
-
     _encodes_none = True
     _python_types = (bool, type(None))
 
@@ -522,6 +516,7 @@ class SetType(ListType):
 
 
 class ListOfItems(ArrayType):
+    """Array"""
 
     item_types = None  # must be set in subclasses
 
@@ -616,6 +611,7 @@ class KeyValueDictionaryType(DictionaryType):
 
 
 class SambaLogonHours(ListType):
+    """Samba Logon Hours"""
 
     item_type = StringType
     _weekdays = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat')
@@ -632,6 +628,7 @@ class SambaLogonHours(ListType):
 
 
 class AppcenterTranslation(KeyValueDictionaryType):
+    """Appcenter Translation"""
 
     key_type = StringType
     value_type = StringType
@@ -646,6 +643,7 @@ class AppcenterTranslation(KeyValueDictionaryType):
 
 
 class UnixTimeinterval(IntegerType):
+    """UNIX Time inerval"""
 
     def decode_value(self, value):
         return self.syntax.to_integer(value)
